@@ -83,10 +83,8 @@ void WiredConnectionWidget::loadConfig(const NetworkManager::Setting::Ptr &setti
     }
 }
 
-QVariantMap WiredConnectionWidget::setting(bool agentOwned) const
+QVariantMap WiredConnectionWidget::setting() const
 {
-    Q_UNUSED(agentOwned);
-
     NetworkManager::WiredSetting wiredSetting;
 
     wiredSetting.setMacAddress(NetworkManager::macAddressFromString(m_widget->macAddress->hwAddress()));
@@ -126,6 +124,11 @@ void WiredConnectionWidget::generateRandomClonedMac()
         int random = qrand() % 255;
         mac[i] = random;
     }
+
+    // Disable the multicast bit and enable the locally administered bit.
+    mac[0] = mac[0] & ~0x1;
+    mac[0] = mac[0] |  0x2;
+
     m_widget->clonedMacAddress->setText(NetworkManager::macAddressAsString(mac));
 }
 
